@@ -46,3 +46,17 @@ def hex2rgb(hexcolours, normalize=False, alpha=None):
 
     return rgbcolours
 
+##########################################################
+def create_meshgrid(x, y, nx=100, ny=100, relmargin=.1):
+    """Create a meshgrid considering @x and @y bounds with @nx, @ny tiles
+    and relative margins @relmargins"""
+
+    marginx = (max(x) - min(x)) * relmargin
+    marginy = (max(y) - min(y)) * relmargin
+    xrange = [np.min(x) - marginx, np.max(x) + marginx]
+    yrange = [np.min(y) - marginy - .15, np.max(y) + marginy]
+    dx = (xrange[1] - xrange[0]) / nx
+    dy = (yrange[1] - yrange[0]) / ny
+    xx, yy = np.mgrid[xrange[0]:xrange[1]:(nx*1j), yrange[0]:yrange[1]:(ny*1j)]
+    return xx, yy, dx, dy
+
